@@ -4,7 +4,7 @@
 application init
 """
 
-default_app_config = "timezones.apps.AaTimezonesConfig"
+default_app_config: str = "timezones.apps.AaTimezonesConfig"
 
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 __title__ = "Time Zones"
